Package: clinDataReview
Type: Package
Title: Clinical Data Review Tool
Version: 1.5.2
Date: 2024-05-17
Authors@R: c(
  person(given = "Laure", family = "Cougnaud", role = c("aut", "cre"), 
  email = "laure.cougnaud@openanalytics.eu"),
  person(given = "Michela", family = "Pasetto", role = "aut", 
  email = "michela.pasetto@openanalytics.eu"),
  person(given = "Lennart", family = "Tuijnder", role = "aut"),
   person(given = "Adriaan", family = "Blommaert", role = "aut"),
  person(given = "Arne", family = "De Roeck", role = c("ctb", "rev"), 
   comment = "rev: tests"),
  person(given = "Open Analytics", role = "cph")
  )
Description: Creation of interactive tables, listings and figures ('TLFs') 
  and associated report for exploratory analysis of data in a clinical trial, 
  e.g. for clinical oversight activities.
  Interactive figures include sunburst, treemap, scatterplot, line plot and
  barplot of counts data. 
  Interactive tables include table of summary statistics
  (as counts of adverse events, enrollment table) and listings.
  Possibility to compare data (summary table or listing) across two data batches/sets.
  A clinical data review report is created via study-specific configuration 
  files and template 'R Markdown' reports contained in the package.
Imports: bookdown, clinUtils (>= 0.1.0), crosstalk, data.table,
        ggplot2, haven, htmltools, htmlwidgets, knitr, jsonlite,
        jsonvalidate, methods, plotly, plyr, rmarkdown, stats, stringr,
        utils, tools, yaml, xml2, xfun
Suggests: countrycode, inTextSummaryTable (>= 3.1.0),
        patientProfilesVis (>= 0.12.0), testthat, DT, scales, grDevices
SystemRequirements: pandoc (to create a clinical data review report)
URL: https://github.com/openanalytics/clinDataReview
BugReports: https://github.com/openanalytics/clinDataReview/issues
License: MIT + file LICENSE
VignetteBuilder: knitr
RoxygenNote: 7.3.1
NeedsCompilation: no
Packaged: 2024-05-17 13:37:36 UTC; root
Author: Laure Cougnaud [aut, cre],
  Michela Pasetto [aut],
  Lennart Tuijnder [aut],
  Adriaan Blommaert [aut],
  Arne De Roeck [ctb, rev] (rev: tests),
  Open Analytics [cph]
Maintainer: Laure Cougnaud <laure.cougnaud@openanalytics.eu>
Repository: CRAN
Date/Publication: 2024-05-17 16:30:05 UTC
Built: R 4.2.3; ; 2024-05-17 18:41:21 UTC; unix
