# Generated by roxygen2: do not edit by hand

S3method(knit_print,clinDataReview)
S3method(knit_print,clinDataReviewMetadata)
S3method(print,clinDataReview)
export(annotateData)
export(barplotClinData)
export(boxplotClinData)
export(checkConfigFile)
export(collapseHtmlContent)
export(convertReportToAspx)
export(createClinDataReviewReportSkeleton)
export(createPatientProfileVar)
export(createRedirectPage)
export(errorbarClinData)
export(filterData)
export(forceParams)
export(formatHoverText)
export(formatPlotlyClinData)
export(getExtraDirs)
export(getJsDepClinDataReview)
export(getMdHeader)
export(getMetadata)
export(getParamsFromConfig)
export(getPathHyperlink)
export(getPathTemplate)
export(getPlotTableVars)
export(gitbook_clinDataReview_report)
export(html_clinDataReview_report)
export(knitPrintClinDataReview)
export(plotCountClinData)
export(postProcessReport)
export(processData)
export(render_clinDataReviewReport)
export(scatterplotClinData)
export(sunburstClinData)
export(tableClinData)
export(timeProfileIntervalPlot)
export(transformData)
export(treemapClinData)
export(varToFm)
export(zipClinDataReview)
import(plotly)
importFrom(bookdown,gitbook)
importFrom(clinUtils,clinColors)
importFrom(clinUtils,clinLinetypes)
importFrom(clinUtils,clinShapes)
importFrom(clinUtils,formatVarForPlotLabel)
importFrom(clinUtils,getClinDT)
importFrom(clinUtils,getColorPalette)
importFrom(clinUtils,getLabelVar)
importFrom(clinUtils,getLabelVars)
importFrom(clinUtils,getLinetypePalette)
importFrom(clinUtils,getShapePalette)
importFrom(clinUtils,knitPrintListObjects)
importFrom(clinUtils,loadDataADaMSDTM)
importFrom(clinUtils,simpleCap)
importFrom(crosstalk,SharedData)
importFrom(crosstalk,bscols)
importFrom(crosstalk,filter_select)
importFrom(data.table,rbindlist)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,facet_grid)
importFrom(ggplot2,facet_wrap)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggplot_build)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_discrete_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_x_discrete)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,scale_y_discrete)
importFrom(ggplot2,sym)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_bw)
importFrom(ggplot2,wrap_dims)
importFrom(haven,write_xpt)
importFrom(htmltools,br)
importFrom(htmltools,browsable)
importFrom(htmltools,div)
importFrom(htmltools,htmlDependency)
importFrom(htmltools,img)
importFrom(htmltools,knit_print.shiny.tag.list)
importFrom(htmltools,tagList)
importFrom(htmltools,tags)
importFrom(htmlwidgets,JS)
importFrom(htmlwidgets,onRender)
importFrom(htmlwidgets,prependContent)
importFrom(jsonlite,toJSON)
importFrom(jsonvalidate,json_validator)
importFrom(knitr,image_uri)
importFrom(knitr,kable)
importFrom(knitr,knit_print)
importFrom(methods,formalArgs)
importFrom(parallel,makeCluster)
importFrom(parallel,parLapply)
importFrom(parallel,stopCluster)
importFrom(plotly,highlight)
importFrom(plotly,layout)
importFrom(plyr,colwise)
importFrom(plyr,ddply)
importFrom(plyr,dlply)
importFrom(plyr,rbind.fill)
importFrom(rmarkdown,html_document)
importFrom(rmarkdown,pandoc_metadata_arg)
importFrom(rmarkdown,render)
importFrom(rmarkdown,resolve_output_format)
importFrom(rmarkdown,yaml_front_matter)
importFrom(stats,as.formula)
importFrom(stats,complete.cases)
importFrom(stats,na.omit)
importFrom(stats,reshape)
importFrom(stats,setNames)
importFrom(stringr,fixed)
importFrom(stringr,str_split)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(utils,capture.output)
importFrom(utils,hasName)
importFrom(utils,head)
importFrom(utils,modifyList)
importFrom(utils,packageVersion)
importFrom(utils,sessionInfo)
importFrom(utils,tail)
importFrom(utils,zip)
importFrom(xfun,read_utf8)
importFrom(xfun,write_utf8)
importFrom(xml2,read_xml)
importFrom(xml2,xml_text)
importFrom(yaml,read_yaml)
importFrom(yaml,write_yaml)
importFrom(yaml,yaml.load)
